summaryrefslogtreecommitdiffstats
path: root/chrome/browser/browser.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/browser.cc')
-rw-r--r--chrome/browser/browser.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/browser.cc b/chrome/browser/browser.cc
index f0d4207..4b5234e 100644
--- a/chrome/browser/browser.cc
+++ b/chrome/browser/browser.cc
@@ -1662,9 +1662,9 @@ void Browser::OpenURLFromTab(TabContents* source,
}
}
- // If this is an application we can only have one tab so a new tab always
- // goes into a tabbed browser window.
- if (disposition != NEW_WINDOW && type_ & TYPE_APP) {
+ // If this is not a normal window (such as a popup or an application), we can
+ // only have one tab so a new tab always goes into a tabbed browser window.
+ if (disposition != NEW_WINDOW && type_ != TYPE_NORMAL) {
// If the disposition is OFF_THE_RECORD we don't want to create a new
// browser that will itself create another OTR browser. This will result in
// a browser leak (and crash below because no tab is created or selected).